[%

    title = 'Account Confirmation' ;
    crumb3_name = 'Admin' ;
    crumb3_href = '/' ;
    crumb2_name = 'User' ;
    crumb2_href = '/user-edit' ;
    crumb1_name = 'Confirmation' ;

%]

<p>That user profile has now been confirmed.</p>

<p>Please <a href="/user-login">click here</a> to log into the rest of the site.</p>
